;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "lsp-shader" "20250722.2024"
  "LSP Clients for ShaderLab."
  '((emacs    "28.1")
    (lsp-mode "6.1"))
  :url "https://github.com/shader-ls/lsp-shader"
  :commit "13d696b8d8ab5ca319cc5e4ae4a1045eae2a2413"
  :revdesc "13d696b8d8ab"
  :keywords '("convenience" "shader")
  :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
  :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
